@@ -3,7 +3,10 @@
 """
 
 from casymda.visualization.entity_visualizer import EntityVisualizer
+from casymda.visualization.tilemap.tilemap_visualizer_interface import (
+    TilemapVisualizerInterface,
+)
 
 
-class TilemapVisualizer(EntityVisualizer):
+class TilemapVisualizer(EntityVisualizer, TilemapVisualizerInterface):
     """ visualizes entity positions at a given canvas """
